==> python-card-framework-0.4.1.tar.gz: python-card-framework-0.4.1/card_framework/v2/widgets/color.py <==
# Copyright 2022 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
from dataclasses import dataclass, field
from typing import Any, Optional

from dataclasses_json import LetterCase, config, dataclass_json

from card_framework import standard_field


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class Color(object):
  red: Optional[float] = standard_field()
  green: Optional[float] = standard_field()
  blue: Optional[float] = standard_field()
  alpha: Optional[float] = standard_field()

  def __setattr__(self, __name: str, __value: Any) -> None:
    """Sets attributes.

    This is overridden to ensure that one and only one of action and open_link
    can be set. If an attempt is made to set both, the already set one will be
    automatically cleared back to 'None'.

    If an attempt is being made to set a value to 'None', then no checks are
    performed, the value is just passed on.

    Args:
        __name (str): The name of the property to set.
        __value (Any): The value to set the property to.

    Returns:
        _type_: _description_
    """
    if __value:
      if __value < 0 or __value > 1:
        raise ValueError('Color or alpha values must be between 0 and 1.')

    super().__setattr__(__name, __value)

==> python-card-framework-1.0.0.tar.gz: python-card-framework-1.0.0/card_framework/v2/widgets/color.py <==
# Copyright 2022 Google Inc. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
import dataclasses
from typing import Any, Optional

import dataclasses_json

from card_framework import standard_field


@dataclasses_json.dataclass_json
@dataclasses.dataclass
class Color(object):
  red: Optional[float] = standard_field()
  green: Optional[float] = standard_field()
  blue: Optional[float] = standard_field()
  alpha: Optional[float] = standard_field()

  def __setattr__(self, __name: str, __value: Any) -> None:
    """Sets attributes.

    This is overridden to ensure that one and only one of action and open_link
    can be set. If an attempt is made to set both, the already set one will be
    automatically cleared back to 'None'.

    If an attempt is being made to set a value to 'None', then no checks are
    performed, the value is just passed on.

    Args:
        __name (str): The name of the property to set.
        __value (Any): The value to set the property to.

    Returns:
        _type_: _description_
    """
    if __value:
      if __value < 0 or __value > 1:
        raise ValueError('Color or alpha values must be between 0 and 1.')

    super().__setattr__(__name, __value)
